| ccCell-class | R Documentation |
A cell container that belongs to a particular sector.
sector.indexcharacter. It is the index that corresponds to the sector.
geomslist. The elements in the list should all be of type ccCellGeom or ccGenomicCellGeom.
NULL
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.